==> haskell-expiring-cache-map-0.0.6.1-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-JaYvCrNw4LiLmphUwFMK2q
key: expiring-cache-map-0.0.6.1-JaYvCrNw4LiLmphUwFMK2q
license: BSD3
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
author: Edward L. Blake
exposed: True
indefinite: False
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
abi: ea0cb54527355a7f8c98077e92b60df7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-JaYvCrNw4LiLmphUwFMK2q
depends:
    base-4.10.1.0 containers-0.5.10.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-Dol3XOpYy8Y47YsAwWAdPB
key: expiring-cache-map-0.0.6.1-Dol3XOpYy8Y47YsAwWAdPB
license: BSD-3-Clause
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
author: Edward L. Blake
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
abi: 6f0c0339291d99d80ccce8b2062835c7
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-Dol3XOpYy8Y47YsAwWAdPB
depends:
    base-4.11.1.0 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
